# TODOs for pylcddc

# High priority 
- Write tests for pre-existing functionality
- Implement support for setting client attributes
- Find out precisely what characters need to be escaped 
- Include a protocol version abstraction layer

# Low priority 
- Add a custom widget type and demonstration for user widgets
- Add delta updates